@@ -1,8 +1,11 @@
-import deskbar.interfaces.Action
-from gettext import gettext as _
 from deskbar.core.Utils import url_show_file
+from gettext import gettext as _
 from os.path import exists
+import deskbar.interfaces.Action
 import gnomevfs
+import logging
+
+LOGGER = logging.getLogger(__name__) 
 
 class OpenFileAction(deskbar.interfaces.Action):
     """
@@ -22,16 +25,28 @@ class OpenFileAction(deskbar.interfaces.Action):
     def get_icon(self):
         return "gtk-open"
     
-    def is_valid(self):
+    def _get_unesacped_url_without_protocol(self):
         url = self._url[7:]
         if not self._escape:
             url = gnomevfs.unescape_string_for_display(url)
+        return url
+    
+    def is_valid(self):
+        url = self._get_unesacped_url_without_protocol()
 
         if not exists(url):
+            LOGGER.debug("File %s does not exist", url)
             return False
         else:
-            mime_type = gnomevfs.get_mime_type(url)
-            return gnomevfs.mime_get_default_application(mime_type) != None
+            try:
+                mime_type = gnomevfs.get_mime_type(url)
+                returnval = gnomevfs.mime_get_default_application(mime_type) != None
+            except RuntimeError, e:
+                # get_mime_type throws a RuntimeException when something went wrong
+                returnval = False
+        if not returnval:
+            LOGGER.debug("File %s has no default application", url)
+        return returnval
     
     def get_hash(self):
         return self._url
@@ -41,3 +56,6 @@ class OpenFileAction(deskbar.interfaces.Action):
     
     def activate(self, text=None):
         url_show_file(self._url, escape=self._escape)
+        
+    def get_tooltip(self, text=None):
+        return self._get_unesacped_url_without_protocol()
