@@ -34,6 +34,8 @@ if is_preferred_browser("firefox") or is_preferred_browser("iceweasel"):
 # Minimum and maximum version of Firefox
 MIN_FF_VERSION = [2, 0, 0, 0]
 MAX_FF_VERSION = [3, 0, 0, 0] # exclusively
+MIN_FF_VERSION_STRING = "2.0.0.0"
+MAX_FF_VERSION_STRING = "3.0.0.0"
         
 # File returned here should be checked for existence
 def get_mozilla_home_file(needed_file):    
@@ -68,6 +70,7 @@ def get_firefox_home_file(needed_file):
 def get_firefox_version():
     browser = get_preferred_browser ()
     process = subprocess.Popen(browser + " -version", stdout=subprocess.PIPE, shell=True)
+    process.wait()
     info = process.stdout.readline().split(" ")
     pattern = re.compile("([0-9]+?)\.([0-9]+?)(\.([0-9]+))*")
     version = None
@@ -107,14 +110,13 @@ PRIMARY_SEARCH_ENGINE = "Google"
 try:
     if USING_FIREFOX:
         prefs_file = file(get_firefox_home_file("prefs.js"))
-    else:
-        # TODO - similar functionality for old-school mozilla (not firefox)
-        prefs_file = None
-    for line in prefs_file:
-        if line.startswith('user_pref("browser.search.selectedEngine", "'):
-            line = line.strip()
-            PRIMARY_SEARCH_ENGINE = line[len('user_pref("browser.search.selectedEngine", "'):-len('");')]
-            break
+        for line in prefs_file:
+            if line.startswith('user_pref("browser.search.selectedEngine", "'):
+                line = line.strip()
+                PRIMARY_SEARCH_ENGINE = line[len('user_pref("browser.search.selectedEngine", "'):-len('");')]
+                break
+        prefs_file.close()
+    # TODO - similar functionality for old-school mozilla (not firefox)
 except:
     pass
 
@@ -209,11 +211,12 @@ class MozillaBookmarksHandler(deskbar.interfaces.Module):
     def has_requirements():
         if is_preferred_browser("mozilla"):
             return True
-        elif is_preferred_browser("firefox"):
+        elif is_preferred_browser("firefox") or is_preferred_browser("iceweasel"):
             if MozillaBookmarksHandler.has_firefox_version():
                 return True
-            # TODO: mark as i18n
-            MozillaBookmarksHandler.INSTRUCTIONS = "Firefox version must be between 2.0.0.0 and 3.0.0.0"
+            
+            MozillaBookmarksHandler.INSTRUCTIONS = \
+                _("Firefox version must be at least %s and less than %s") % (MIN_FF_VERSION_STRING, MAX_FF_VERSION_STRING)
             return False
         else:
             MozillaBookmarksHandler.INSTRUCTIONS = _("Mozilla/Firefox is not your preferred browser.")
@@ -272,6 +275,7 @@ class MozillaSearchHandler(deskbar.interfaces.Module):
         self.watcher.remove_all()
         
     def query(self, query):
+        self.set_priority_for_matches (self._smart_bookmarks)
         if SHOW_ONLY_PRIMARY and PRIMARY_SEARCH_ENGINE != None:
             for s in self._smart_bookmarks:
                 if s.get_name() == PRIMARY_SEARCH_ENGINE:
@@ -291,8 +295,9 @@ class MozillaSearchHandler(deskbar.interfaces.Module):
     def has_requirements():
         if is_preferred_browser("firefox") or is_preferred_browser("iceweasel"):
             if is_preferred_browser("firefox") and not MozillaBookmarksHandler.has_firefox_version():
-                # TODO: mark as i18n
-                MozillaSearchHandler.INSTRUCTIONS = "Firefox version must be between 2.0.0.0 and 3.0.0.0"
+                
+                MozillaSearchHandler.INSTRUCTIONS = \
+                    _("Firefox version must be at least %s and less than %s") % (MIN_FF_VERSION_STRING, MAX_FF_VERSION_STRING)
                 return False
             
             # Correct firefox version or iceweasel
@@ -326,7 +331,8 @@ class MozillaBookmarksParser(HTMLParser.HTMLParser):
                 self.indexed_file = self._index_mozilla()
             self.close()
         except Exception, e:
-            LOGGER.error('Could not index Firefox bookmarks: %s' % e)
+            LOGGER.error('Could not index Firefox bookmarks')
+            LOGGER.exception(e)
         
     def get_indexer(self):
         """
@@ -344,7 +350,8 @@ class MozillaBookmarksParser(HTMLParser.HTMLParser):
                 self.feed(file(bookmarks_file).read())
                 return bookmarks_file
         except Exception, msg:
-            LOGGER.error('Retrieving Mozilla Bookmarks: %s' % msg)
+            LOGGER.error('Retrieving Mozilla Bookmarks')
+            LOGGER.exception(msg)
         
     def _index_firefox(self):
         try:
@@ -353,7 +360,8 @@ class MozillaBookmarksParser(HTMLParser.HTMLParser):
                 self.feed(file(bookmarks_file).read())
                 return bookmarks_file
         except Exception, msg:
-            LOGGER.error('Retrieving Firefox Bookmarks: %s' % msg)
+            LOGGER.error('Retrieving Firefox Bookmarks')
+            LOGGER.exception(msg)
     
     def handle_starttag(self, tag, attrs):
         tag = tag.lower()
@@ -433,7 +441,7 @@ class Firefox2SearchEngineParser :
         try:
             self._parse_image (xml)
         except Exception, msg:
-            LOGGER.error("Parsing icon for %s\n%s" % (self.filename,msg))
+            LOGGER.error("Parsing icon for %s\n%s", self.filename, msg)
     
     def _detect_namespace (self, xml):
         # Manually added search engines use the "os" namespace
@@ -595,7 +603,7 @@ class MozillaSmartBookmarksParser:
             parent_dir = self.f[:self.f.rindex("/")]
             return [img for img in glob.glob(join(parent_dir, '%s.*' % self.f[:-4])) if not img.endswith(".src")][0]
         except Exception, msg:
-            LOGGER.warning("Error detecting icon for smart bookmark:%s\n%s" % (self.f,msg))
+            LOGGER.warning("Error detecting icon for smart bookmark:%s\n%s", self.f, msg)
             return None
     
     def _handle_token(self, state, tokens):
@@ -767,7 +775,7 @@ class MozillaSmartBookmarksDirParser:
                 self._smart_bookmarks.append(bookmark)
                 
             except Exception, msg:
-                LOGGER.error('MozillaSmartBookmarksDirParser:cannot parse smart bookmark: %s\n%s' % (f,msg))
+                LOGGER.error('MozillaSmartBookmarksDirParser:cannot parse smart bookmark: %s\n%s', f, msg)
                     
     
     def get_smart_bookmarks(self):
@@ -821,11 +829,12 @@ class MozillaHistoryHandler(deskbar.interfaces.Module):
     def has_requirements():
         if is_preferred_browser("mozilla"):
             return True
-        elif is_preferred_browser("firefox"):
+        elif is_preferred_browser("firefox") or is_preferred_browser("iceweasel"):
             if MozillaBookmarksHandler.has_firefox_version():
                 return True
-            # TODO: mark as i18n
-            MozillaHistoryHandler.INSTRUCTIONS = "Firefox version must be between 2.0.0.0 and 3.0.0.0"
+            
+            MozillaHistoryHandler.INSTRUCTIONS = \
+                _("Firefox version must be at least %s and less than %s") % (MIN_FF_VERSION_STRING, MAX_FF_VERSION_STRING)
             return False
         else:
             MozillaHistoryHandler.INSTRUCTIONS = _("Mozilla/Firefox is not your preferred browser.")
